@@ -14,4 +14,4 @@ mod document;
 mod pagination;
 mod syntax_highlight;
 
-pub use crate::syntax_highlight::{list_syntax_themes, list_syntaxes};
+pub use crate::syntax_highlight::SyntaxHighlight;
