@@ -2,7 +2,6 @@ use std::io::Write;
 
 use crate::error;
 use itertools::Itertools;
-use lazy_static::lazy_static;
 use liquid_core::error::ResultLiquidReplaceExt;
 use liquid_core::parser::TryMatchToken;
 use liquid_core::Language;
@@ -14,37 +13,39 @@ use pulldown_cmark as cmark;
 use pulldown_cmark::Event::{self, End, Html, Start, Text};
 
 #[cfg(not(feature = "syntax-highlight"))]
-use engarde::Raw as Highlight;
+pub use engarde::Raw as SyntaxHighlight;
 #[cfg(feature = "syntax-highlight")]
-use engarde::Syntax as Highlight;
-
-lazy_static! {
-    static ref HIGHLIGHT: Highlight = Highlight::new();
-}
+pub use engarde::Syntax as SyntaxHighlight;
 
 #[cfg(feature = "syntax-highlight")]
-pub fn has_syntax_theme(name: &str) -> error::Result<bool> {
-    Ok(HIGHLIGHT.has_theme(name))
+fn has_syntax_theme(syntax: &SyntaxHighlight, name: &str) -> error::Result<bool> {
+    Ok(syntax.has_theme(name))
 }
 
 #[cfg(not(feature = "syntax-highlight"))]
-pub fn has_syntax_theme(name: &str) -> error::Result<bool> {
+fn has_syntax_theme(syntax: &SyntaxHighlight, name: &str) -> error::Result<bool> {
     failure::bail!("Themes are unsupported in this build.");
 }
 
-pub fn list_syntax_themes() -> Vec<String> {
-    HIGHLIGHT.themes().collect()
-}
-
-pub fn list_syntaxes() -> Vec<String> {
-    HIGHLIGHT.syntaxes().collect()
+fn verify_theme(syntax: &SyntaxHighlight, theme: Option<&str>) -> error::Result<()> {
+    if let Some(theme) = &theme {
+        match has_syntax_theme(syntax, theme) {
+            Ok(true) => {}
+            Ok(false) => failure::bail!("Syntax theme '{}' is unsupported", theme),
+            Err(err) => {
+                log::warn!("Syntax theme named '{}' ignored. Reason: {}", theme, err);
+            }
+        };
+    }
+    Ok(())
 }
 
 #[derive(Clone, Debug)]
 struct CodeBlock {
+    syntax: std::sync::Arc<SyntaxHighlight>,
     lang: Option<liquid::model::KString>,
     code: String,
-    theme: liquid::model::KString,
+    theme: Option<liquid::model::KString>,
 }
 
 impl Renderable for CodeBlock {
@@ -56,7 +57,8 @@ impl Renderable for CodeBlock {
         write!(
             writer,
             "{}",
-            HIGHLIGHT.format(&self.code, self.lang.as_deref(), Some(self.theme.as_str()))
+            self.syntax
+                .format(&self.code, self.lang.as_deref(), self.theme.as_deref())
         )
         .replace("Failed to render")?;
 
@@ -66,12 +68,20 @@ impl Renderable for CodeBlock {
 
 #[derive(Clone, Debug)]
 pub struct CodeBlockParser {
-    syntax_theme: liquid::model::KString,
+    syntax: std::sync::Arc<SyntaxHighlight>,
+    syntax_theme: Option<liquid::model::KString>,
 }
 
 impl CodeBlockParser {
-    pub fn new(syntax_theme: liquid::model::KString) -> Self {
-        Self { syntax_theme }
+    pub fn new(
+        syntax: std::sync::Arc<SyntaxHighlight>,
+        theme: Option<liquid::model::KString>,
+    ) -> error::Result<Self> {
+        verify_theme(&syntax, theme.as_deref())?;
+        Ok(Self {
+            syntax,
+            syntax_theme: theme,
+        })
     }
 }
 
@@ -122,6 +132,7 @@ impl liquid_core::ParseBlock for CodeBlockParser {
         tokens.assert_empty();
 
         Ok(Box::new(CodeBlock {
+            syntax: self.syntax.clone(),
             code: content,
             lang,
             theme: self.syntax_theme.clone(),
@@ -131,19 +142,26 @@ impl liquid_core::ParseBlock for CodeBlockParser {
 
 pub struct DecoratedParser<'a> {
     parser: cmark::Parser<'a, 'a>,
+    syntax: std::sync::Arc<SyntaxHighlight>,
     theme: Option<&'a str>,
     lang: Option<String>,
     code: Option<Vec<pulldown_cmark::CowStr<'a>>>,
 }
 
 impl<'a> DecoratedParser<'a> {
-    pub fn new(parser: cmark::Parser<'a, 'a>, theme: Option<&'a str>) -> Self {
-        DecoratedParser {
+    pub fn new(
+        parser: cmark::Parser<'a, 'a>,
+        syntax: std::sync::Arc<SyntaxHighlight>,
+        theme: Option<&'a str>,
+    ) -> error::Result<Self> {
+        verify_theme(&syntax, theme)?;
+        Ok(DecoratedParser {
             parser,
+            syntax,
             theme,
             lang: None,
             code: None,
-        }
+        })
     }
 }
 
@@ -172,9 +190,9 @@ impl<'a> Iterator for DecoratedParser<'a> {
             Some(End(cmark::Tag::CodeBlock(_))) => {
                 let html = if let Some(code) = self.code.as_deref() {
                     let code = code.iter().join("\n");
-                    HIGHLIGHT.format(&code, self.lang.as_deref(), self.theme)
+                    self.syntax.format(&code, self.lang.as_deref(), self.theme)
                 } else {
-                    HIGHLIGHT.format("", self.lang.as_deref(), self.theme)
+                    self.syntax.format("", self.lang.as_deref(), self.theme)
                 };
                 // reset highlighter
                 self.lang = None;
@@ -189,9 +207,10 @@ impl<'a> Iterator for DecoratedParser<'a> {
 
 pub fn decorate_markdown<'a>(
     parser: cmark::Parser<'a, 'a>,
+    syntax: std::sync::Arc<SyntaxHighlight>,
     theme_name: Option<&'a str>,
-) -> DecoratedParser<'a> {
-    DecoratedParser::new(parser, theme_name)
+) -> error::Result<DecoratedParser<'a>> {
+    DecoratedParser::new(parser, syntax, theme_name)
 }
 
 #[cfg(test)]
@@ -224,8 +243,9 @@ mod test_syntsx {
 
     #[test]
     fn highlight_block_renders_rust() {
+        let syntax = std::sync::Arc::new(SyntaxHighlight::new());
         let highlight: Box<dyn liquid_core::ParseBlock> =
-            Box::new(CodeBlockParser::new("base16-ocean.dark".into()));
+            Box::new(CodeBlockParser::new(syntax, Some("base16-ocean.dark".into())).unwrap());
         let parser = liquid::ParserBuilder::new()
             .block(highlight)
             .build()
@@ -267,9 +287,10 @@ mod test_syntsx {
 
         let mut buf = String::new();
         let parser = cmark::Parser::new(&html);
+        let syntax = std::sync::Arc::new(SyntaxHighlight::new());
         cmark::html::push_html(
             &mut buf,
-            decorate_markdown(parser, Some("base16-ocean.dark")),
+            decorate_markdown(parser, syntax, Some("base16-ocean.dark")).unwrap(),
         );
         snapbox::assert_eq(MARKDOWN_RENDERED, &buf);
     }
@@ -298,8 +319,9 @@ mod test_raw {
 
     #[test]
     fn codeblock_renders_rust() {
+        let syntax = std::sync::Arc::new(SyntaxHighlight::new());
         let highlight: Box<dyn liquid_core::ParseBlock> =
-            Box::new(CodeBlockParser::new("base16-ocean.dark".into()));
+            Box::new(CodeBlockParser::new(syntax, Some("base16-ocean.dark".into())).unwrap());
         let parser = liquid::ParserBuilder::new()
             .block(highlight)
             .build()
@@ -334,9 +356,10 @@ mod test_raw {
 
         let mut buf = String::new();
         let parser = cmark::Parser::new(&html);
+        let syntax = std::sync::Arc::new(SyntaxHighlight::new());
         cmark::html::push_html(
             &mut buf,
-            decorate_markdown(parser, Some("base16-ocean.dark")),
+            decorate_markdown(parser, syntax, Some("base16-ocean.dark")).unwrap(),
         );
         assert_eq!(buf, MARKDOWN_RENDERED);
     }
